@@ -109,7 +109,7 @@
             var category = d.category,
               cls = '';
             if (category && category.toLowerCase() === 'alarm') {
-              var severity = d.operational_severity;
+              var severity = d.vitrage_operational_severity;
               if (severity) {
                 switch (severity.toLowerCase()) {
                   case 'critical':
@@ -137,7 +137,7 @@
                 return n.id == d.id;
               });
 
-              var state = reald.operational_state;
+              var state = reald.vitrage_operational_state;
               if (state) {
                 switch (state.toLowerCase()) {
                   case 'error':
@@ -161,7 +161,7 @@
             if (category && category.toLowerCase() === 'alarm') {
               icon_size = '18px';
             } else {
-              var type = d.type || 'no_type';
+              var type = d.vitrage_type || 'no_type';
               switch (type.toLowerCase()) {
                 case 'nova.instance':
                 case 'nova.host':
@@ -192,7 +192,7 @@
           })
           .classed('icon', true)
           .classed('fill-only', function(d) {
-            var type = (d.type || '').toLowerCase();
+            var type = (d.vitrage_type || '').toLowerCase();
             if (type && type === 'nova.host' || type === 'cinder.volume') {
               return true;
             }
@@ -203,7 +203,7 @@
             if (category && category.toLowerCase() === 'alarm') {
               icon = '\uf0f3'; //\uf0a2'; //bell-o
             } else {
-              var type = d.type || 'no_type';
+              var type = d.vitrage_type || 'no_type';
               switch (type.toLowerCase()) {
                 case 'nova.instance':
                   icon = '\uf108'; //fa-desktop
